@@ -14,21 +14,15 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use crate::testnet2::{parameters::SystemParameters, Testnet2Components};
-use snarkvm_algorithms::traits::{CommitmentScheme, CRH};
-use snarkvm_gadgets::{
-    integers::uint::UInt8,
-    traits::{
-        algorithms::{CRHGadget, CommitmentGadget},
-        alloc::AllocGadget,
-    },
-};
-use snarkvm_r1cs::{errors::SynthesisError, Assignment, ConstraintSynthesizer, ConstraintSystem};
+use crate::testnet2::Testnet2Components;
+use snarkvm_algorithms::prelude::*;
+use snarkvm_gadgets::prelude::*;
+use snarkvm_r1cs::{Assignment, ConstraintSynthesizer, ConstraintSystem, SynthesisError};
 
 /// Always-accept program
 pub struct NoopCircuit<C: Testnet2Components> {
-    /// System parameters
-    pub system_parameters: Option<SystemParameters<C>>,
+    /// Local data commitment parameters
+    pub local_data_commitment_parameters: <C::LocalDataCommitment as CommitmentScheme>::Parameters,
     /// Commitment to the program input.
     pub local_data_root: Option<<C::LocalDataCRH as CRH>::Output>,
     /// Record position
@@ -36,21 +30,21 @@ pub struct NoopCircuit<C: Testnet2Components> {
 }
 
 impl<C: Testnet2Components> NoopCircuit<C> {
-    pub fn blank(system_parameters: &SystemParameters<C>) -> Self {
+    pub fn blank(local_data_commitment_parameters: &<C::LocalDataCommitment as CommitmentScheme>::Parameters) -> Self {
         Self {
-            system_parameters: Some(system_parameters.clone()),
+            local_data_commitment_parameters: local_data_commitment_parameters.clone(),
             local_data_root: Some(<C::LocalDataCRH as CRH>::Output::default()),
             position: 0u8,
         }
     }
 
     pub fn new(
-        system_parameters: &SystemParameters<C>,
+        local_data_commitment_parameters: &<C::LocalDataCommitment as CommitmentScheme>::Parameters,
         local_data_root: &<C::LocalDataCRH as CRH>::Output,
         position: u8,
     ) -> Self {
         Self {
-            system_parameters: Some(system_parameters.clone()),
+            local_data_commitment_parameters: local_data_commitment_parameters.clone(),
             local_data_root: Some(local_data_root.clone()),
             position,
         }
@@ -62,7 +56,6 @@ impl<C: Testnet2Components> ConstraintSynthesizer<C::InnerScalarField> for NoopC
         &self,
         cs: &mut CS,
     ) -> Result<(), SynthesisError> {
-        let system_parameters = self.system_parameters.get_ref()?;
         let local_data_root = self.local_data_root.get_ref()?;
         let position = self.position;
 
@@ -71,7 +64,7 @@ impl<C: Testnet2Components> ConstraintSynthesizer<C::InnerScalarField> for NoopC
         let _local_data_commitment_parameters_gadget =
             <C::LocalDataCommitmentGadget as CommitmentGadget<_, _>>::ParametersGadget::alloc_input(
                 &mut cs.ns(|| "Declare local data commitment parameters"),
-                || Ok(system_parameters.local_data_commitment.parameters().clone()),
+                || Ok(self.local_data_commitment_parameters.clone()),
             )?;
 
         let _local_data_root_gadget = <C::LocalDataCRHGadget as CRHGadget<_, _>>::OutputGadget::alloc_input(
