@@ -17,16 +17,16 @@
 use crate::errors::AccountError;
 use snarkvm_algorithms::traits::{CommitmentScheme, EncryptionScheme, SignatureScheme};
 
-use rand::Rng;
+use rand::{CryptoRng, Rng};
 
 pub trait AccountScheme: Sized {
-    type AccountAddress: Default;
-    type AccountPrivateKey;
+    type Address: Default;
+    type PrivateKey;
     type CommitmentScheme: CommitmentScheme;
     type EncryptionScheme: EncryptionScheme;
     type SignatureScheme: SignatureScheme;
 
-    fn new<R: Rng>(
+    fn new<R: Rng + CryptoRng>(
         signature_parameters: &Self::SignatureScheme,
         commitment_parameters: &Self::CommitmentScheme,
         encryption_parameters: &Self::EncryptionScheme,
